"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const test_1 = require("@oclif/test");
const fs = require("fs");
const path = require("path");
const waitOn = require("wait-on");
const rimraf = require("rimraf");
const test_utils_1 = require("../__tests__/test-utils");
require("chai");
const COMMAND = 'swagger-ui';
const TEST_PORT = 5552;
describe(COMMAND, () => {
    describe('server', () => {
        afterEach(() => {
            // emit disconnect to stop the server
            process.emit('disconnect');
        });
        test_1.test
            .stdout()
            .command([COMMAND, (0, test_utils_1.resourcePath)('openapi.yml'), '-p', `${TEST_PORT}`])
            .it('runs swagger-ui', async (ctx) => {
            await waitOn({ resources: [`tcp:localhost:${TEST_PORT}`] });
            (0, test_1.expect)(ctx.stdout).to.contain('running');
        });
    });
    describe('--bundle', () => {
        const bundleDir = 'static';
        afterEach(() => {
            rimraf.sync(bundleDir);
        });
        test_1.test
            .stdout()
            .command([COMMAND, (0, test_utils_1.resourcePath)('openapi.yml'), '--bundle', bundleDir])
            .it('bundles swagger-ui', (ctx) => {
            (0, test_1.expect)(fs.existsSync(path.join(bundleDir))).to.equal(true);
            (0, test_1.expect)(fs.existsSync(path.join(bundleDir, 'index.html'))).to.equal(true);
            (0, test_1.expect)(fs.existsSync(path.join(bundleDir, 'openapi.json'))).to.equal(true);
            (0, test_1.expect)(fs.existsSync(path.join(bundleDir, 'swagger-ui.js'))).to.equal(true);
        });
    });
});
