"use strict";
var _a;
Object.defineProperty(exports, "__esModule", { value: true });
const yargs_1 = require("yargs");
const openapi_client_axios_1 = require("openapi-client-axios");
const config_1 = require("../common/config");
const definition_1 = require("../common/definition");
const testConfig = (0, config_1.getConfigValue)('tests');
const argv = (0, yargs_1.default)(process.argv.slice(2))
    .option('header', { alias: 'H', type: 'string', array: true })
    .option('server', { alias: 'S', type: 'string', array: true })
    .option('inject', { alias: 'I', type: 'string', array: true })
    .option('apiRoot', { alias: 'R', type: 'string' })
    .parseSync();
const definition = (0, definition_1.resolveDefinition)((_a = argv[0]) !== null && _a !== void 0 ? _a : (0, config_1.getConfigValue)('definition'));
let api;
beforeAll(async () => {
    const document = await (0, definition_1.parseDefinition)({
        definition,
        servers: argv.server,
        inject: argv.inject,
        header: argv.header,
        induceServers: true,
    });
    api = new openapi_client_axios_1.default({ definition: document });
    await api.init();
});
for (const operationId of Object.keys(testConfig)) {
    describe(operationId, () => {
        for (const testName of Object.keys(testConfig[operationId])) {
            describe(testName, () => {
                const testDefinition = testConfig[operationId][testName];
                if (testDefinition.checks.includes('Success2XX')) {
                    test('should return 2XX response', async () => {
                        const client = await api.getClient();
                        const res = await client[operationId](testDefinition.request.params, testDefinition.request.data, testDefinition.request.config);
                        expect(res.status).toBeGreaterThanOrEqual(200);
                        expect(res.status).toBeLessThan(300);
                    });
                }
            });
        }
    });
}
